@@ -16,16 +16,20 @@ syntaxis.
 package Bio::Polloc::Polloc::Config;
 use base qw(Bio::Polloc::Polloc::Root Bio::Polloc::Polloc::IO);
 use strict;
+our $VERSION = 1.0503; # [a-version] from Bio::Polloc::Polloc::Version
+
 
 =head1 GLOBALS
 
 Global variables controling the behavior of the package
 
+=over
+
 =cut
 
 our($CFGMAXDEPTH, $CFGCURDEPTH);
 
-=head2 CFGMAXDEPTH
+=item CFGMAXDEPTH
 
 Maximum depth of variables replacement
 
@@ -33,10 +37,12 @@ Maximum depth of variables replacement
 
 $CFGMAXDEPTH = 7 unless defined $CFGMAXDEPTH;
 
-=head2 CFGCURDEPTH
+=item CFGCURDEPTH
 
 Current depth of replacement (internal var)
 
+=back
+
 =cut
 
 $CFGCURDEPTH = 0;
@@ -47,9 +53,13 @@ Methods provided by the package
 
 =head2 new
 
+=over
+
+=item 
+
 Initialization method.
 
-=head3 Arguments
+=item Arguments
 
 =over
 
@@ -61,7 +71,9 @@ parsed.
 =item -noparse I<bool (int)>
 
 If set to true, does not automatically parse the file on creation.  If so,
-the L<parse()> function must be manually called.
+the L<parse> function must be manually called.
+
+=back
 
 =back
 
@@ -76,12 +88,18 @@ sub new {
 
 =head2 parse
 
+=over
+
+=item 
+
 Parses the configuration file.
 
-=head3 Throws
+=item Throws
 
 L<Bio::Polloc::Polloc::IOException> on parsing error.
 
+=back
+
 =cut
 
 sub parse {
@@ -124,8 +142,14 @@ sub parse {
 
 =head2 spaces
 
+=over
+
+=item 
+
 Gets/sets the spaces to be parsed.
 
+=back
+
 =cut
 
 sub spaces {
@@ -141,9 +165,13 @@ sub spaces {
 
 =head2 value
 
+=over
+
+=item 
+
 Gets the value of a given key.
 
-=head3 Arguments
+=item Arguments
 
 =over
 
@@ -165,10 +193,12 @@ If true, does not alert if not found.
 
 =back
 
-=head3 Throws
+=item Throws
 
 L<Bio::Polloc::Polloc::Error> If not found and mandatory.
 
+=back
+
 =cut
 
 sub value {
@@ -191,9 +221,13 @@ sub value {
 
 =head2 all_keys
 
+=over
+
+=item 
+
 Gets all the stored keys.
 
-=head3 Arguments
+=item Arguments
 
 =over
 
@@ -203,10 +237,12 @@ The parent space.  By default C<.>.
 
 =back
 
-=head3 Returns
+=item Returns
 
 All the keys within the space (array of str).
 
+=back
+
 =cut
 
 sub all_keys {
@@ -219,9 +255,13 @@ sub all_keys {
 
 =head2 alias
 
- a key by alias.
+=over
 
-=head3 Arguments
+=item 
+
+A key by alias.
+
+=item Arguments
 
 =over
 
@@ -235,10 +275,12 @@ The B<to> key name.
 
 =back
 
-=head3 Throws
+=item Throws
 
 L<Bio::Polloc::Polloc::Error> if any of the two keys is empty.
 
+=back
+
 =cut
 
 sub alias {
@@ -264,8 +306,14 @@ Methods intended to be used only within the scope of Bio::Polloc::*
 
 =head2 _filter_line
 
+=over
+
+=item 
+
 Removes comments from lines and lines with spaces only.
 
+=back
+
 =cut
 
 sub _filter_line {
@@ -282,9 +330,13 @@ sub _filter_line {
 
 =head2 _save
 
+=over
+
+=item 
+
 Saves a key/value pair.
 
-=head3 Arguments
+=item Arguments
 
 =over
 
@@ -303,10 +355,12 @@ The value.
 
 =back
 
-=head3 Returns
+=item Returns
 
 The (uniform) key of the saved pair.  If array or list, the key and the value.
 
+=back
+
 =cut
 
 sub _save {
@@ -341,16 +395,22 @@ sub _save {
 
 =head2 _parse_space
 
+=over
+
+=item 
+
 Parses (cleans) the name of a namespace.
 
-=head3 Arguments
+=item Arguments
 
 The namespace to parse.
 
-=head3 Returns
+=item Returns
 
 The parsed (uniform) namespace.
 
+=back
+
 =cut
 
 sub _parse_space {
@@ -364,17 +424,23 @@ sub _parse_space {
 
 =head2 _space_required
 
-Indicates whether a namespace is required.  I.e., if the user explicitly
+=over
+
+=item 
+
+Indicates whether a namespace is required.  I<I.e.>, if the user explicitly
 requiested the space, any child or any parent.
 
-=head3 Arguments
+=item Arguments
 
 The namespace.
 
-=head3 Returns
+=item Returns
 
 Boolean (int).
 
+=back
+
 =cut
 
 sub _space_required {
@@ -398,9 +464,13 @@ sub _space_required {
 
 =head2 _execute_token
 
+=over
+
+=item 
+
 Executes a token expected to map to a function.
 
-=head3 Arguments 
+=item Arguments 
 
 =over
 
@@ -419,6 +489,8 @@ function.
 
 =back
 
+=back
+
 =cut
 
 sub _execute_token {
@@ -446,8 +518,14 @@ sub _execute_token {
 
 =head2 _execute_postparse
 
+=over
+
+=item 
+
 Executes registered functions to be launched once parsing is finnished.
 
+=back
+
 =cut
 
 sub _execute_postparse {
@@ -472,9 +550,13 @@ sub _execute_postparse {
 
 =head2 _register_handle_function
 
+=over
+
+=item 
+
 Register a handle function (for tokens).
 
-=head3 Arguments
+=item Arguments
 
 =over
 
@@ -503,6 +585,8 @@ Namespace of the token.
 
 =back
 
+=back
+
 =cut
 
 sub _register_handle_function {
@@ -517,9 +601,13 @@ sub _register_handle_function {
 
 =head2 _register_postparse_function
 
+=over
+
+=item 
+
 Registers a function to be launched once parsing is complete.
 
-=head3 Arguments
+=item Arguments
 
 =over
 
@@ -537,6 +625,8 @@ The parameters to be passed to the function.
 
 =back
 
+=back
+
 =cut
 
 sub _register_postparse_function {
@@ -549,8 +639,14 @@ sub _register_postparse_function {
 
 =head2 _handle_functions
 
+=over
+
+=item 
+
 Gets the collection of functions to handle tokens.
 
+=back
+
 =cut
 
 sub _handle_functions {
@@ -561,8 +657,14 @@ sub _handle_functions {
 
 =head2 _postparse_functions
 
+=over
+
+=item 
+
 Gets the collection of functions to be launched after parsing.
 
+=back
+
 =cut
 
 sub _postparse_functions {
@@ -573,9 +675,13 @@ sub _postparse_functions {
 
 =head2 _get_handle_function
 
+=over
+
+=item 
+
 Gets the handle function for the given token.
 
-=head3 Arguments
+=item Arguments
 
 =over
 
@@ -585,6 +691,8 @@ The token.
 
 =back
 
+=back
+
 =cut
 
 sub _get_handle_function {
@@ -596,9 +704,15 @@ sub _get_handle_function {
 
 =head2 _reparse
 
+=over
+
+=item 
+
 Parses recursively all values until no references to other vars last or
 the maximum depth is reached, whatever happens first.
 
+=back
+
 =cut
 
 sub _reparse {
@@ -627,9 +741,13 @@ sub _reparse {
 
 =head2 _parse_key
 
+=over
+
+=item 
+
 Parses a key and returns its uniform name.
 
-=head3 Arguments
+=item Arguments
 
 =over
 
@@ -643,6 +761,8 @@ The namespace.
 
 =back
 
+=back
+
 =cut
 
 sub _parse_key {
@@ -663,17 +783,23 @@ sub _parse_key {
 
 =head2 _key_alias
 
-Creates an alias for a key based on a string input.  See L<alias()>.
+=over
 
-=head3 Arguments
+=item 
+
+Creates an alias for a key based on a string input.  See L<alias>.
+
+=item Arguments
 
 A string containing the name of the B<from> key, one or more spaces and the name
 of the B<to> string.  Can contain surrounding spaces.
 
-=head3 Throws
+=item Throws
 
 L<Bio::Polloc::Polloc::Error> if empty string or not properly formatted.
 
+=back
+
 =cut
 
 sub _key_alias {
