@@ -16,7 +16,6 @@ use Bio::Polloc::Polloc::IO;
 use Bio::Polloc::Polloc::Error;
 use Error qw(:try);
 
-
 =head1 GLOBALS
 
 Global variables controling the behavior of the package
@@ -31,7 +30,8 @@ The package's version
 
 =cut
 
-# From v1.5.2 onwards it's inherited from Bio::Polloc::Polloc::Version
+our $VERSION = 1.0503; # [a-version] from Bio::Polloc::Polloc::Version
+
 
 =head2 VERBOSITY
 
@@ -285,6 +285,24 @@ sub vardump {
 	}
 }
 
+=head2 rrmdir
+
+Recursively removes a directory.
+
+=cut
+
+sub rrmdir {
+   my ($self, $dir) = @_;
+   return unless -d $dir;
+   while(my $file = <$dir/*>){
+      next if $file =~ /^\.\.?$/;
+      $file = Bio::Polloc::Polloc::IO->catfile($dir, $file);
+      if(-d $file){ $self->rrmdir($file) }
+      else { unlink $file }
+   }
+   rmdir $dir;
+}
+
 =head1 INTERNAL METHODS
 
 Methods intended to be used only witin the scope of Bio::Polloc::*
