@@ -25,6 +25,8 @@ L<Bio::Polloc::Polloc::IO>
 package Bio::Polloc::RuleIO;
 use strict;
 use base qw(Bio::Polloc::Polloc::Root Bio::Polloc::Polloc::IO);
+our $VERSION = 1.0503; # [a-version] from Bio::Polloc::Polloc::Version
+
 
 =head1 PUBLIC METHODS
 
@@ -46,6 +48,10 @@ The same arguments of L<Bio::Polloc::Polloc::IO>, plus:
 
 The format of the file
 
+=item -genomes
+
+The genomes to be scaned
+
 =back
 
 =cut
@@ -70,6 +76,8 @@ sub new {
          my $self = $class->SUPER::new(@args);
 	 $self->debug("Got the RuleIO class $class ($1)");
 	 $self->format($1);
+	 my ($genomes) = $self->_rearrange([qw(GENOMES)], @args);
+	 $self->genomes($genomes);
          $self->_initialize(@args);
          return $self;
       }
@@ -236,7 +244,7 @@ sub groupcriteria {
 
 =head2 grouprules
 
-Alias of L<groupcriteria()> (for backwards-compatibility).
+Alias of L<groupcriteria> (for backwards-compatibility).
 
 =cut
 
@@ -314,6 +322,7 @@ sub execute {
    my $locigroup = Bio::Polloc::LociGroup->new(
    		-name=>'Full collection - '.time().".".rand(1000),
    		-genomes=>$self->genomes);
+   $self->throw("Impossible to execute without genomes") unless defined $self->genomes;
    for my $gk (0 .. $#{$self->genomes}){
       my $genome = $self->genomes->[$gk];
       $self->_end_rules_loop;
