@@ -32,6 +32,8 @@ use base qw(Bio::Polloc::Typing::bandingPattern);
 use strict;
 use Bio::Polloc::Polloc::IO;
 use Bio::Polloc::LocusI;
+our $VERSION = 1.0503; # [a-version] from Bio::Polloc::Polloc::Version
+
 
 =head1 APPENDIX
 
@@ -71,6 +73,7 @@ sub fragments {
    my ($locigroup) = $self->_rearrange([qw(LOCIGROUP)], @args);
    defined $locigroup or $self->throw('Trying to amplify fragments, but no loci group provided');
    my $primers = $self->design_primers(-locigroup=>$locigroup);
+   return unless defined $primers;
    UNIVERSAL::can($primers, 'isa') and $primers->isa('Bio::Polloc::Polloc::IO')
    		or $self->throw('Wrong primers file', $primers, 'Bio::Polloc::Polloc::UnexpectedException');
    defined $primers->file or $self->throw('Impossible to locate primers temporal file', $primers, 'Bio::Polloc::Polloc::UnexpectedException');
@@ -201,7 +204,7 @@ sub flanking_size {
 
 =head2 annealing_errors
 
-Gets/sets the maximum number of errors allowed for a primer to anneal.
+Gets/sets the maximum percentage of errors allowed for a primer to anneal.
 0 by default.
 
 =cut
