@@ -1,12 +1,14 @@
 #!/usr/bin/perl
 
 use strict;
-use Bio::Polloc::RuleIO 1.5010;
+use Bio::Polloc::RuleIO 1.0501;
 use Bio::Polloc::LocusIO;
 use Bio::Polloc::Genome;
 use Bio::SeqIO;
 use List::Util qw(min max);
 
+use Pod::Usage;
+
 # ------------------------------------------------- METHODS
 # Output methods
 sub csv_header();
@@ -21,46 +23,22 @@ sub advance_extension($$); # group, Ngroups
 my $cnf = shift @ARGV;
 our $out = shift @ARGV;
 my $buildgroups = shift @ARGV;
+$buildgroups = '' if $buildgroups =~ /off/i;
 my $extendgroups = shift @ARGV;
+$extendgroups = '' if $extendgroups =~ /off/i;
 my $summarizegroups = shift @ARGV;
+$summarizegroups = '' if $summarizegroups =~ /off/i;
 my @names = split ":", shift @ARGV;
 my @inseqs = @ARGV;
 my $csv = "$out.csv";
 my $groupcsv = "$out.group.csv";
-unless($cnf and $out and $buildgroups and defined $extendgroups
-	and defined $summarizegroups and $#inseqs>-1){
-die <<HELP
 
-   polloc_vntrs.pl - Scans genomes searching for VNTRs, compares and groups
-   the found loci, extends the groups based on homology and produce detailed
-   per-group reports.
-   
-   Usage: $0 [Params]
-   Params, in that order:
-      cnf (path):	Path to the configuration file (.cnf or .bme).
-      			Example: t/vntrs.bme
-      out (path):	Path to the base of the output files.
-      			Example: /tmp/polloc-vntrs.out
-      buildgroups:	If on, groups the detected loci.
-      			Values: 'on' or '' (empty string)
-      extendgroups:	If on, extends the groups of loci (buildgroups
-      			must be on).
-			Values: 'on' or '' (empty string)
-      summarizegroups:	If on, creates files with additional information
-      			about groups (buildgroups must be on).
-			Values: 'on' or '' (empty string)
-      names (str):	The names of the genomes separated by colons (:).
-      			Alternatively, can be an empty string ('') to
-			assign genome names from files.
-      			Example: Xci3:Xeu8:XamC
-      inseqs (paths):	Sequences to scan (input).  Each argument will be
-      			considered a single genome, and the values of
-			'names' will be applied.  The order of the inseqs
-			must be the same of the names.
-			Example: /data/Xci3.fa /data/Xeu8.fa /data/XamC.fa
-      
-HELP
-}
+pod2usage(1)	unless $cnf
+		and $out
+		and defined $buildgroups
+		and defined $extendgroups
+		and defined $summarizegroups
+		and $#inseqs>-1;
 
 Bio::Polloc::Polloc::Root->DEBUGLOG(-file=>">$out.log");
 Bio::Polloc::Polloc::Root->VERBOSITY(4);
@@ -248,6 +226,12 @@ __END__
 
 Luis M. Rodriguez-R < lmrodriguezr at gmail dot com >
 
+=head1 DESCRIPTION
+
+This script is the core of the VNTRs analysis tool
+(L<http://bioinfo-prod.mpl.ird.fr/xantho/utils/#vntrs>).  It requires the C<vntrs.bme>
+file, at the C<examples> folder.  Run it with no arguments to check the required parameters.
+
 =head1 LICENSE
 
 This script is distributed under the terms of
@@ -261,30 +245,37 @@ The arguments must be in the following order:
 
 =over
 
-=item 1
+=item Configuration
 
-The configuration file (a .bme file).
+The configuration file (a .bme or .cfg file).
 
-=item 2
+=item Output
 
 Output base, a path to the prefix of the files to be created.
 
-=item 3
+=item Build groups
 
-Extend groups: Any non-empty string to extend the groups, or
-empty string to avoid extension.
+Any non-empty string to create groups of loci, or empty string
+to avoid grouping.  If empty (C<''>), extension and summary are
+ignored.
 
-=item 4
+=item Extend groups
 
-Summarize groups: Any non-empty string to produce additional
-summaries per group, or empty string to avoid summaries.
+Any non-empty string to extend the groups, or empty string to
+avoid extension.
 
-=item 5
+=item Summarize groups
+
+Any non-empty string to produce additional summaries per group,
+or empty string to avoid summaries.
+
+=item Names
 
 The identifiers (names) of the input genomes in a single string
-separated by colons (:).
+separated by colons (C<:>).  Alternatively, use an empty string
+(C<''>) to use names based on the filename.
 
-=item 6
+=item Inseqs
 
 All the following arguments will be treated as input files.  Each
 file is assumed to contain a genome (that can contain one or more
@@ -295,5 +286,31 @@ sequence) in [multi-]fasta format.
 Run C<perl polloc_vntrs.pl> without arguments to see the help
 message.
 
+=head1 SEE ALSO
+
+=over
+
+=item *
+
+L<Bio::Polloc::RuleIO>
+
+=item *
+
+L<Bio::Polloc::Genome>
+
+=item *
+
+L<Bio::Polloc::LocusI>
+
+=item *
+
+L<Bio::Polloc::LocusIO>
+
+=item *
+
+L<Bio::Polloc::LociGroup>
+
+=back
+
 =cut
 
